@@ -190,8 +190,8 @@ timeout_response_cb (GtkDialog *dialog, int response_id, gpointer data)
         TimeoutDialog *timeout = data;
 
         if (response_id == GTK_RESPONSE_DELETE_EVENT) {
-                /* The user closed the dialog, presumably saying, "go away, everything is fine" */
-                timeout->response_id = GTK_RESPONSE_ACCEPT;
+                /* The user closed the dialog or pressed ESC, revert */
+                timeout->response_id = GTK_RESPONSE_CANCEL;
         } else
                 timeout->response_id = response_id;
 
@@ -215,8 +215,8 @@ user_says_things_are_ok (GsdXrandrManager *manager)
         timeout.countdown = 10;
         print_countdown_text (&timeout);
 
-        gtk_dialog_add_button (GTK_DIALOG (timeout.dialog), _("Restore the previous configuration"), GTK_RESPONSE_CANCEL);
-        gtk_dialog_add_button (GTK_DIALOG (timeout.dialog), _("Keep this configuration"), GTK_RESPONSE_ACCEPT);
+        gtk_dialog_add_button (GTK_DIALOG (timeout.dialog), _("_Restore Previous Configuration"), GTK_RESPONSE_CANCEL);
+        gtk_dialog_add_button (GTK_DIALOG (timeout.dialog), _("_Keep This Configuration"), GTK_RESPONSE_ACCEPT);
         gtk_dialog_set_default_response (GTK_DIALOG (timeout.dialog), GTK_RESPONSE_ACCEPT); /* ah, the optimism */
 
         g_signal_connect (timeout.dialog, "response",
@@ -224,9 +224,9 @@ user_says_things_are_ok (GsdXrandrManager *manager)
                           &timeout);
 
         gtk_widget_show_all (timeout.dialog);
-        timeout_id = g_timeout_add (1000,
-                                    timeout_cb,
-                                    &timeout);
+        timeout_id = g_timeout_add_seconds (1,
+                                            timeout_cb,
+                                            &timeout);
         gtk_main ();
 
         gtk_widget_destroy (timeout.dialog);
